@@ -8,12 +8,14 @@ import logging
 import argparse
 from urllib.parse import urljoin
 
-import yaml
 import json
 from os import path
 
+import yaml
+import pandas as pd
+
 from diadmin.metadata_api import catalog, container
-from diadmin.utils.utils import add_defaultsuffix, mksubdir
+from diadmin.utils.utils import add_defaultsuffix, mksubdir,get_system_id
 
 def main() :
     logging.basicConfig(level=logging.INFO)
@@ -22,7 +24,7 @@ def main() :
     # command line args
     #
     description =  "Upload and download catalog items."
-    achoices = ['hierarchies','connections','containers','tags']
+    achoices = ['hierarchies','connections','containers','tags','metadata']
     parser = argparse.ArgumentParser(description=description)
     help_config = 'Specifies config_demo.yaml file with the parameters: URL, TENANT, USER, PWD'
     parser.add_argument('type',choices=achoices, help = "Catalog type [connections,containers] only download..")
@@ -43,16 +45,19 @@ def main() :
     conn = {'url': urljoin(params['URL'] , '/app/datahub-app-metadata/api/v1'),
             'auth':(params['TENANT']+'\\'+ params['USER'],params['PWD'])}
 
+    sysid = get_system_id(params['URL'],params['TENANT'])
+
     catalog_directory = mksubdir('.','catalogs')
 
     if args.download :
         if args.type == 'hierarchies':
             hfilter = None if args.item == '*' else args.item
             filename = 'hierarchies.json' if args.item == '*' else args.item+'.json'
+            filename = path.join(catalog_directory,filename)
             logging.info(f"Download hierarchies to {filename}")
             hierarchies = catalog.download_hierarchies(conn,hierarchy_name=hfilter)
             logging.info(f"Save file {filename}")
-            with open(path.join(catalog_directory,filename),'w') as fp:
+            with open(filename,'w') as fp:
                 json.dump(hierarchies,fp,indent=4)
 
         elif args.type == 'connections':
@@ -96,6 +101,11 @@ def main() :
             with open(tags_file,'w') as fp:
                 json.dump(tags,fp,indent=4)
 
+        elif args.type == 'metadata':
+            df = container.export_catalog(conn)
+            filename = path.join('catalogs','metadata_'+sysid+'.csv')
+            df.to_csv(filename,index = False)
+
     if args.upload :
         if args.type == 'hierarchies':
             if args.item == '*':
