@@ -17,7 +17,7 @@ import yaml
 from diadmin.utils.utils import add_defaultsuffix, toggle_mockapi
 from diadmin.vctl_cmds.login import di_login
 from diadmin.vctl_cmds.vrep import import_object, solution_to_repo, import_menue_panel,VFLOW_PATHS
-from diadmin.utils.utils import read_userlist, get_operator_generation
+#from diadmin.utils.utils import
 
 # global variable
 root_dir = '.'
