@@ -82,6 +82,13 @@ def get_operator_generation(dir) :
         gen = 2
     return gen
 
+
+########## Get di system id
+def get_system_id(cluster,tenant):
+    disystem = re.match('.+vsystem\.ingress\.([a-zA-Z0-9-_]+)\.([a-zA-Z0-9-_]+).+',cluster)
+    return disystem.group(1) + '.' + disystem.group(2) + '_'+ tenant
+
+######### Files
 class csvlist :
     def __init__(self,filename,keys=None):
         self.filename = filename
@@ -180,4 +187,5 @@ def mksubdirs(*args) :
     adir = dirs_list[0]
     for i in range(1,len(dirs_list)) :
         mksubdir(adir,dirs_list[i])
-        adir = path.join(adir,dirs_list[i])
\ No newline at end of file
+        adir = path.join(adir,dirs_list[i])
+
